@@ -4,7 +4,6 @@ OC.L10N.register(
     "Details" : "Detalles",
     "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
-    "General settings" : "Configuraciones generales",
     "Rename" : "Renombrar",
     "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
@@ -12,13 +11,16 @@ OC.L10N.register(
     "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
+    "Cancel" : "Cancelar",
     "Add" : "Agregar",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
+    "Sort by" : "Ordenar por",
     "Save" : "Guardar",
-    "Cancel" : "Cancelar",
+    "Close" : "Cerrar",
+    "Create" : "Crear",
     "Invalid image" : "Imagen inválida",
     "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
@@ -29,7 +31,6 @@ OC.L10N.register(
     "None" : "Ninguno",
     "Member" : "Miembro",
     "New contact" : "Nuevo contacto",
-    "Close" : "Cerrar",
     "Import" : "Importar",
     "Not grouped" : "No agrupado",
     "User" : "Usuario",
@@ -92,6 +93,7 @@ OC.L10N.register(
     "Male" : "Masculino",
     "Unknown" : "Desconocido",
     "Loading contacts …" : "Cargando contactos ...",
+    "General settings" : "Configuraciones generales",
     "Search contacts …" : "Buscar contactos ..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
