@@ -11,19 +11,21 @@ OC.L10N.register(
     "Download" : "Discargar",
     "Share with users or groups" : "Compartir con usatores o gruppos",
     "can edit" : "pote modificar",
+    "Cancel" : "Cancellar",
     "Add" : "Adder",
     "First name" : "Prime nomine",
     "Last name" : "Ultime nomine",
     "Display name" : "Monstrar nomine",
+    "Sort by" : "Arrangiar per",
     "Save" : "Salveguardar",
-    "Cancel" : "Cancellar",
+    "Close" : "Clauder",
+    "Create" : "Crear",
     "Invalid image" : "Imagine invalide",
     "Name" : "Nomine",
     "Title" : "Titulo",
     "Pending" : "Pendente",
     "None" : "Nulle",
     "New contact" : "Nove contacto",
-    "Close" : "Clauder",
     "Import" : "Importar",
     "Not grouped" : "Non gruppate",
     "User" : "User",
