@@ -13,13 +13,17 @@ OC.L10N.register(
     "Share with users or groups" : "Bagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
     "can edit" : "dapat menyunting",
+    "Cancel" : "Membatalkan",
     "Add" : "Masukkan",
     "First name" : "Nama depan",
     "Last name" : "Nama belakang",
     "Display name" : "Nama tampilan",
     "Last modified" : "Terakhir diubah",
+    "Sort by" : "Urut berdasarkan",
     "Save" : "Simpan",
-    "Cancel" : "Membatalkan",
+    "Close" : "Tutup",
+    "Folder name" : "Nama Folder",
+    "Create" : "Membuat",
     "Invalid image" : "Gambar tidak sah",
     "Name" : "Nama",
     "Title" : "Judul",
@@ -27,7 +31,6 @@ OC.L10N.register(
     "Pending" : "Tunggu",
     "None" : "Tidak ada",
     "New contact" : "Kontak baru",
-    "Close" : "Tutup",
     "Import" : "Impor",
     "Not grouped" : "Tidak dikelompokkan",
     "User" : "Pengguna",
