@@ -22,9 +22,7 @@ OC.L10N.register(
     "Leave team" : "チームを離脱",
     "Delete team" : "チームを削除",
     "Contacts settings" : "連絡先の設定",
-    "General settings" : "一般設定",
     "Update avatars from social media" : "SNSでアバターをアップデート",
-    "(refreshed once per week)" : "(週に1回更新)",
     "Address books" : "アドレス帳",
     "Rename" : "名前を変更",
     "Export" : "エクスポート",
@@ -58,7 +56,6 @@ OC.L10N.register(
     "Unshare {addressbook}?" : "{addressbook}の共有を解除しますか?",
     "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
     "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
-    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
     "Download" : "ダウンロード",
     "Show" : "表示",
     "Unshare from me" : "共有を自分から解除",
@@ -77,6 +74,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
     "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
     "Add new address book" : "新しいアドレス帳を追加する",
+    "Cancel" : "キャンセル",
     "Add" : "Add",
     "First name" : "名",
     "Last name" : "姓",
@@ -84,7 +82,7 @@ OC.L10N.register(
     "Phonetic last name" : "せい",
     "Display name" : "表示名",
     "Last modified" : "最終更新日",
-    "Sort by {sorting}" : "{sorting} で整列",
+    "Sort by" : "ソート",
     "Manages" : "管理",
     "Oversees" : "統括",
     "An error happened during the config change" : "構成の変更中にエラーが発生しました",
@@ -93,12 +91,14 @@ OC.L10N.register(
     "Save" : "保存",
     "Change unique password" : "固有パスワードを変更",
     "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
+    "Close" : "閉じる",
     "There is no description for this team" : "このチームの説明はありません",
     "Enter a description for the team" : "チームの説明を入力します",
+    "Conversation name" : "会話名",
     "Team name" : "チーム名",
     "Edit" : "編集",
-    "Cancel" : "キャンセル",
     "Request to join" : "参加リクエスト",
+    "Create" : "作成",
     "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
     "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
     "Members" : "メンバー",
@@ -198,7 +198,6 @@ OC.L10N.register(
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 件の連絡先を {name} に追加しました"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 件の連絡先を {name} に追加中"],
     "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
-    "Close" : "閉じる",
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
     "No data for this contact" : "この連絡先のデータはありません",
@@ -308,6 +307,10 @@ OC.L10N.register(
     "Unable to delete contact" : "連絡先を削除できません。",
     "Loading contacts …" : "連絡先を読み込み中...",
     "Loading …" : "読み込み中…",
+    "General settings" : "一般設定",
+    "(refreshed once per week)" : "(週に1回更新)",
+    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
+    "Sort by {sorting}" : "{sorting} で整列",
     "Unique password …" : "固有パスワード...",
     "Search contacts …" : "連絡先を検索...",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
