@@ -4,7 +4,6 @@ OC.L10N.register(
     "Details" : "დეტალები",
     "All contacts" : "ყველა კონტაქტი",
     "Contacts" : "კონტაქტები",
-    "General settings" : "მთავარი პარამეტრები",
     "Rename" : "სახელის შეცვლა",
     "Send email" : "ელ-წერილის გაგზავნა",
     "Delete" : "გაუქმება",
@@ -12,13 +11,16 @@ OC.L10N.register(
     "Download" : "ჩამოტვირთვა",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
     "can edit" : "შეუძლია შეცვლა",
+    "Cancel" : "უარყოფა",
     "Add" : "დამატება",
     "First name" : "სახელი",
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
     "Last modified" : "ბოლო ცვლილება",
+    "Sort by" : "დალაგება",
     "Save" : "შენახვა",
-    "Cancel" : "უარყოფა",
+    "Close" : "დახურვა",
+    "Create" : "შექმნა",
     "Invalid image" : "არასწორი სურათი",
     "Address book" : "მისამართების წიგნი",
     "Name" : "სახელი",
@@ -28,7 +30,6 @@ OC.L10N.register(
     "None" : "არც ერთი",
     "Member" : "წევრი",
     "New contact" : "ახალი კონტაქტი",
-    "Close" : "დახურვა",
     "Import" : "იმპორტი",
     "Not grouped" : "არაა დაჯგუფებული",
     "User" : "მომხმარებელი",
@@ -88,6 +89,7 @@ OC.L10N.register(
     "Male" : "მამრობითი",
     "Unknown" : "ამოუცნობი",
     "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
+    "General settings" : "მთავარი პარამეტრები",
     "Search contacts …" : "მოძებნეთ კონტაქტები ..."
 },
 "nplurals=2; plural=(n!=1);");
