@@ -17,9 +17,7 @@ OC.L10N.register(
     "Create contacts" : "연락처 만들기",
     "Add contacts" : "연락처 추가",
     "Contacts settings" : "연락처 설정",
-    "General settings" : "일반 설정",
     "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
-    "(refreshed once per week)" : "(주 1회 새로고침)",
     "Address books" : "주소록",
     "Rename" : "이름 바꾸기",
     "Export" : "내보내기",
@@ -58,6 +56,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "주소록을 찾을 수 없어서 가져올 수 없습니다.",
     "An error occurred, unable to create the address book" : "오류가 발생하여 주소록을 생성할 수 없습니다.",
     "Add new address book" : "새 주소록 생성",
+    "Cancel" : "취소",
     "Add" : "Add",
     "First name" : "이름",
     "Last name" : "성",
@@ -65,14 +64,17 @@ OC.L10N.register(
     "Phonetic last name" : "성 표음",
     "Display name" : "표시 이름",
     "Last modified" : "수정한 날짜",
-    "Sort by {sorting}" : "{sorting}(으)로 정렬",
+    "Sort by" : "다음으로 정렬",
     "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
     "Save" : "저장",
     "Change unique password" : "독자 암호 변경",
     "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
+    "Close" : "닫기",
+    "Conversation name" : "대화명",
+    "Calendar" : "달력",
     "Edit" : "편집",
-    "Cancel" : "취소",
     "Request to join" : "등록 요청",
+    "Create" : "생성",
     "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
     "Confirm" : "확정",
     "Add more info" : "정보 추가",
@@ -155,7 +157,6 @@ OC.L10N.register(
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
     "_{count} error_::_{count} errors_" : ["{count} 오류 발생"],
-    "Close" : "닫기",
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처를 가져오는 중"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처 가져오기 완료"],
     "Import" : "가져오기",
@@ -241,7 +242,10 @@ OC.L10N.register(
     "Unable to delete contact" : "연락처를 삭제할 수 없음",
     "Loading contacts …" : "연락처 불러오는 중…",
     "Loading …" : "불러오는 중 …",
+    "General settings" : "일반 설정",
+    "(refreshed once per week)" : "(주 1회 새로고침)",
     "{addressbookname} (Disabled)" : "{addressbookname} (비활성화됨)",
+    "Sort by {sorting}" : "{sorting}(으)로 정렬",
     "Unique password …" : "독자 암호 ...",
     "Search contacts …" : "연락처 검색…",
     "Loading members list …" : "회원 목록 불러오는 중 ...",
