@@ -5,6 +5,7 @@ OC.L10N.register(
     "All contacts" : "Бүх харилцагчид",
     "Contacts" : "Харилцагчид",
     "Copy to full name" : "Бүтэн нэр хуулах",
+    "General" : "Ерөнхий",
     "Rename" : "Нэр солих",
     "Delete" : "Устгах",
     "Copied" : "Хуулагдсан",
@@ -13,13 +14,15 @@ OC.L10N.register(
     "Download" : "Татаж авах",
     "Share with users or groups" : "Бусдад түгээх",
     "can edit" : "засаж чадна",
+    "Cancel" : "болиулах",
     "Add" : "нэмэх",
     "First name" : "Нэр",
     "Last name" : "Овог",
     "Display name" : "Харагдах нэр",
     "Last modified" : "Сүүлд өөрчилсөн",
     "Save" : "Хадгалах",
-    "Cancel" : "болиулах",
+    "Close" : "Хаах",
+    "Create" : "Үүсгэх",
     "Invalid image" : "буруу зураг",
     "Upload a new picture" : "Шинэ зураг оруулах",
     "Choose from Files" : "Файлаас сонгох",
@@ -36,7 +39,6 @@ OC.L10N.register(
     "Member" : "Гишүүн",
     "Add member" : "Гишүүн нэмэх",
     "New contact" : "Шинэ харилцагч",
-    "Close" : "Хаах",
     "Import" : "Импорт",
     "Not grouped" : "Багт ороогүй",
     "User" : "Хэрэглэгч",
