@@ -14,12 +14,15 @@ OC.L10N.register(
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
     "can edit" : "poate edita",
+    "Cancel" : "Anulează",
     "Add" : "Add",
     "First name" : "Prenume",
     "Last name" : "Nume",
     "Display name" : "Nume afișat",
+    "Sort by" : "Sortează după",
     "Save" : "Salvează",
-    "Cancel" : "Anulează",
+    "Close" : "Închide",
+    "Create" : "Creează",
     "Invalid image" : "Imagine invalidă",
     "Address book" : "Listă de contacte",
     "Name" : "Nume",
@@ -31,7 +34,6 @@ OC.L10N.register(
     "Select option" : "Selectatți opțiunea",
     "Member" : "Membru",
     "New contact" : "Contact nou ",
-    "Close" : "Închide",
     "Import" : "Importă",
     "Not grouped" : "Negrupate",
     "User" : "Utilizator",
