@@ -7,7 +7,7 @@ OC.L10N.register(
     "A contacts app for Nextcloud" : "Një aplikacion kontaktesh për Nextcloud",
     "Copy to full name" : "Kopje të emrit të plotë ",
     "Omit year" : "Shmang vitin",
-    "General settings" : "Opsjonet e Pergjithshme",
+    "General" : "I përgjithshëm",
     "Rename" : "Riemëro",
     "Send email" : "Dërgo email",
     "Delete" : "Fshije",
@@ -16,13 +16,17 @@ OC.L10N.register(
     "Download" : "Shkarko",
     "Share with users or groups" : "Nda me përdoruesit ose grupet",
     "can edit" : "mund të modifikoni",
+    "Cancel" : "Anullo",
     "Add" : "Shto",
     "First name" : "Emër",
     "Last name" : "Mbiemër",
     "Display name" : "Shfaq emrin",
     "Last modified" : "Ndryshuar së fundmi",
+    "Sort by" : "I renditur nga",
     "Save" : "Ruaj",
-    "Cancel" : "Anullo",
+    "Close" : "Mbylleni",
+    "Folder name" : "Emri i dosjes",
+    "Create" : "Krijoni",
     "Invalid image" : "Figurë e pavlefshme",
     "Pick an avatar" : "Zgjidh një avatar",
     "Error while processing the picture." : "Gabim gjatë procesimit të figurës.",
@@ -50,7 +54,6 @@ OC.L10N.register(
     "None" : "Asnjë",
     "Member" : "Anëtar",
     "New contact" : "Kontakt i ri",
-    "Close" : "Mbylleni",
     "Import" : "Import",
     "Not grouped" : "I pagrupuar",
     "User" : "Përdorues",
@@ -111,6 +114,7 @@ OC.L10N.register(
     "Male" : "Mashkull",
     "Unknown" : "I/E panjohur",
     "Loading contacts …" : "Duke ngarkuar kontaktet ...",
+    "General settings" : "Opsjonet e Pergjithshme",
     "Search contacts …" : "Kërko kontakte ..."
 },
 "nplurals=2; plural=(n != 1);");
