@@ -2,20 +2,23 @@ OC.L10N.register(
     "contacts",
     {
     "Details" : "Detalji",
+    "General" : "Opšte",
     "Rename" : "Rename",
     "Delete" : "Delete",
     "Copy link" : "Kopiraj vezu",
     "Download" : "Preuzmi",
     "can edit" : "može da menja",
-    "Add" : "Dodaj",
-    "Save" : "Sačuvaj",
     "Cancel" : "Otkaži",
+    "Add" : "Dodaj",
+    "Sort by" : "Razvrstaj",
+    "Save" : "Sačuvaj",
+    "Close" : "Zatvori",
+    "Create" : "Napravi",
     "Name" : "naziv",
     "Title" : "Naslov",
     "No results" : "Nema rezultata",
     "Pending" : "Na čekanju",
     "None" : "Ništa",
-    "Close" : "Zatvori",
     "Import" : "Uvezi",
     "User" : "Korisnik",
     "Group" : "Group",
