@@ -4,6 +4,8 @@ OC.L10N.register(
     "Import contacts" : "导入联系人",
     "Details" : "详情",
     "All contacts" : "全部联系人",
+    "_Imported %n contact_::_Imported %n contacts_" : ["已导入 %n 位联系人"],
+    "_Imported %n contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已导入 %n 位联系人（跳过 %d 位）"],
     "Contacts" : "联系人",
     "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud通讯录应用程序是Nextcloud的CardDAV服务器用户界面。您可以轻松使用您的Nextcloud同步各设备上的联系人，并在线上编辑。\n\n* 🚀 **与其他Nextcloud应用程序整合！** 目前有邮件和日历，还会有更多。\n* 🎉 **不会忘记生日！** 您可以将生日与其他重复的活动与您的Nextcloud日历同步。\n* 👥 **分享通讯录！** 您想与您的朋友或同事分享您的联系人吗？没问题！\n* 🙈 **我们不是在重复造轮子！** 基于出色且开源的SabreDAV库。",
@@ -24,9 +26,8 @@ OC.L10N.register(
     "Leave team" : "离开团队",
     "Delete team" : "删除团队",
     "Contacts settings" : "联系人设置",
-    "General settings" : "一般设置",
+    "General" : "普通",
     "Update avatars from social media" : "从社交媒体更新头像",
-    "(refreshed once per week)" : "（每周刷新）",
     "Address books" : "地址簿",
     "Rename" : "重命名",
     "Export" : "导出",
@@ -79,6 +80,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "导入已禁用，因为没有可用的通讯录",
     "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
     "Add new address book" : "添加新通讯录",
+    "Cancel" : "取消",
     "Add" : "添加",
     "First name" : "名",
     "Last name" : "姓",
@@ -86,7 +88,7 @@ OC.L10N.register(
     "Phonetic last name" : "语音姓氏",
     "Display name" : "显示名称",
     "Last modified" : "上一次更改",
-    "Sort by {sorting}" : "以 {sorting} 排序",
+    "Sort by" : "排序",
     "Manages" : "管理",
     "Oversees" : "监督",
     "An error happened during the config change" : "更改配置时发生一个错误",
@@ -96,14 +98,16 @@ OC.L10N.register(
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
+    "Close" : "关闭",
     "There is no description for this team" : "此团队没有描述",
     "Enter a description for the team" : "输入团队的描述",
+    "Conversation name" : "对话名称",
     "An error happened while saving {fields}" : "保存 {fields} 时出错",
     "Team name" : "团队名称",
     "Team owner" : "团队所有者",
     "Edit" : "编辑",
-    "Cancel" : "取消",
     "Request to join" : "请求加入",
+    "Create" : "创建",
     "Your request to join this team is pending approval" : "您加入此团队的请求正在等待批准",
     "You are not a member of {circle}" : "您并非 {circle} 的成员",
     "Members" : "成员",
@@ -223,7 +227,6 @@ OC.L10N.register(
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 位联系人已添加到 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在将 {success} 位联系人添加到 {name}"],
     "_{count} error_::_{count} errors_" : ["{count} 个错误"],
-    "Close" : "关闭",
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在将 %n 位联系人导入 {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 位联系人导入 {addressbook}"],
     "No data for this contact" : "此联系人无数据",
@@ -335,7 +338,10 @@ OC.L10N.register(
     "Unable to delete contact" : "无法删除联系人",
     "Loading contacts …" : "正在加载联系人…",
     "Loading …" : "正在加载…",
+    "General settings" : "一般设置",
+    "(refreshed once per week)" : "（每周刷新）",
     "{addressbookname} (Disabled)" : "{addressbookname}（已禁用）",
+    "Sort by {sorting}" : "以 {sorting} 排序",
     "Unique password …" : "唯一密码…",
     "Search contacts …" : "搜索联系人…",
     "Invite members to team" : "邀请成员加入团队",
