@@ -4,6 +4,8 @@ OC.L10N.register(
     "Import contacts" : "導入聯絡人",
     "Details" : "詳細資料",
     "All contacts" : "所有聯絡人",
+    "_Imported %n contact_::_Imported %n contacts_" : ["已導入 %n 個聯絡人"],
+    "_Imported %n contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已導入 %n 個聯絡人（略過 %d 個）"],
     "Contacts" : "通訊錄",
     "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的用戶界面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們沒有無謂地重複開發！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
@@ -24,9 +26,7 @@ OC.L10N.register(
     "Leave team" : "離開團隊",
     "Delete team" : "刪除團隊",
     "Contacts settings" : " 通訊錄設定",
-    "General settings" : "一般設定",
     "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
-    "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
     "Rename" : "重新命名",
     "Export" : "導出",
@@ -79,6 +79,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
     "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "Add new address book" : "添加新通訊錄",
+    "Cancel" : "取消",
     "Add" : "添加",
     "First name" : "名",
     "Last name" : "姓",
@@ -86,7 +87,7 @@ OC.L10N.register(
     "Phonetic last name" : "音頻姓",
     "Display name" : "顯示名稱",
     "Last modified" : "上次修改",
-    "Sort by {sorting}" : "按 {sorting} 排序",
+    "Sort by" : "排序",
     "Manages" : "管理",
     "Oversees" : "監督",
     "An error happened during the config change" : "配置更改期間發生錯誤",
@@ -96,14 +97,17 @@ OC.L10N.register(
     "Save" : "保存",
     "Change unique password" : "更改獨一無二的密碼",
     "Failed to save password. Please try again later." : "保存密碼失敗。請稍後再試。",
+    "Close" : "關閉",
     "There is no description for this team" : "此團隊沒有描述",
     "Enter a description for the team" : "輸入團隊的描述",
+    "Conversation name" : "對話名稱",
+    "Calendar" : "日曆",
     "An error happened while saving {fields}" : "儲存 {fields} 時發生了錯誤",
     "Team name" : "團隊名字",
     "Team owner" : "團隊所有者",
     "Edit" : "編輯",
-    "Cancel" : "取消",
     "Request to join" : "請求加入",
+    "Create" : "新增",
     "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
     "You are not a member of {circle}" : "您不是 {circle} 的成員",
     "Members" : "成員",
@@ -223,7 +227,6 @@ OC.L10N.register(
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
     "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
-    "Close" : "關閉",
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在導入 %n 個聯絡人至 {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成導入 %n 個聯絡人至 {addressbook}"],
     "No data for this contact" : "此聯絡人沒有數據資料",
@@ -335,7 +338,10 @@ OC.L10N.register(
     "Unable to delete contact" : "無法刪除聯絡人",
     "Loading contacts …" : "正在載入通訊錄 …",
     "Loading …" : "正在載入 …",
+    "General settings" : "一般設定",
+    "(refreshed once per week)" : "（每週重新整理一次）",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "Sort by {sorting}" : "按 {sorting} 排序",
     "Unique password …" : "獨一無二的密碼 ...",
     "Search contacts …" : "搜尋聯絡人…",
     "Invite members to team" : "邀請成員加入團隊",
